# Celeratas

The Latin Programming Language

## Description

Built from python, Celeratas uses a custom ident-oriented syntax that features latin keywords. Although some of the text is written in latin, there is an English help menu with translations for all of the keywords.

## Getting Started

### Dependencies

-   Windows, Macos, Unix, or Linux
-   Python3

### Installing

-   Open the terminal and type:

```
pip3 install Celeratas
```

### Executing program

-   In order to open the Celeratas interactive shell, run the Celeratas package as a script. Open the terminal and type:

```
python3 -m Celeratas
```

-   From there, you can type 'auxilium' (meaning help) to learn about the basics of the language.

```
auxilium
```

-   If you want to read from a file instead, add the file name as an argument.

```
python3 -m Celeratas file_you_want_to_read.clr
```

## Author

Finn Mattis

## Version History

-   1.0.0
    -   The initial release of Celeratas! Integers, Floats, Roman Numerals, Bools, Strings, Arrays, Hash Maps, Variables, Conditionals, Loops, Try-excepts, Functions, and more!

## License

This project is licensed under the MIT License - see the LICENSE file for details
